@@ -2310,8 +2310,17 @@ where
 
     #[emitter]
     fn emit_expr_stmt(&mut self, e: &ExprStmt) -> Result {
+        let expr_span = e.expr.span();
+
         emit!(e.expr);
-        semi!();
+
+        let span = if expr_span.hi == e.span.hi {
+            DUMMY_SP
+        } else {
+            Span::new(expr_span.hi, e.span.hi, Default::default())
+        };
+
+        semi!(span);
     }
 
     #[emitter]
